@@ -143,13 +143,34 @@ void test9() {
   case 3:
     c + d;
   case 4:
-    d;
+    switch (f) {
+    case 1:
+      l;
+      break;
+    case 7:
+      t;
+    }
     break;
   default:
     e;
   }
 }
 
+void test10() {
+  switch (a) {
+  case 1:
+    switch (b) {
+      case 1:
+      break;
+      default:
+        break;
+      }
+      break;
+  default:
+    break;
+  }
+}
+
 int main() {
   int n = read(), m = read();
   for (int i = 1; i <= n; i++) f[i][0] = read();
